@@ -1,4 +1,5 @@
 """Application dependency providers."""
+from __future__ import annotations
 
 from datetime import datetime
 from typing import TYPE_CHECKING
@@ -32,7 +33,7 @@ def provide_id_filter(
 ) -> CollectionFilter[UUID]:
     """
     Args:
-        ids: Parsed out of comma separated list of values in query params.
+        ids: Parsed out of query params.
 
     Returns:
         Type consumed by `AbstractRepository.filter_in_collection()`
@@ -96,8 +97,9 @@ def provide_filter_dependencies(
     id_filter: CollectionFilter[UUID] = Dependency(skip_validation=True),
     limit_offset: LimitOffset = Dependency(skip_validation=True),
 ) -> list[FilterTypes]:
-    """Common collection route filtering dependencies. Add all filters to any
-    route by including this function as a dependency, e.g:
+    """Inject filtering dependencies.
+
+    Add all filters to any route by including this function as a dependency, e.g:
 
     ```python
     @get
@@ -126,7 +128,8 @@ def provide_filter_dependencies(
 
 
 def create_collection_dependencies() -> dict[str, Provide]:
-    """
+    """Build mapping of collection dependencies.
+
     Returns:
         A dictionary of provides for pagination endpoints.
     """
